@@ -620,7 +620,7 @@ describe Braintree::Customer do
           :credit_card => {
             :options => {
               :verify_card => true,
-              :verification_merchant_account_id => SpecHelper::HiperBRLMerchantAccountId,
+              :verification_merchant_account_id => SpecHelper::CardProcessorBRLMerchantAccountId,
               :verification_account_type => "debit",
             }
           },
@@ -1231,6 +1231,27 @@ describe Braintree::Customer do
       expect(result.errors.for(:customer).for(:credit_card).on(:number)[0].message).to eq("Duplicate card exists in the vault.")
     end
 
+    it "does not update customer with duplicate payment method if fail_on_payment_method_for_customer option set" do
+      customer = Braintree::Customer.create!(
+        :credit_card => {
+          :number => 4111111111111111,
+          :expiration_date => "05/2010",
+        },
+      )
+      result = Braintree::Customer.update(
+        customer.id,
+        :credit_card => {
+          :number => 4111111111111111,
+          :expiration_date => "05/2010",
+          :options=> {
+            :fail_on_duplicate_payment_method_for_customer => true
+          }
+        },
+      )
+      expect(result.success?).to eq(false)
+      expect(result.errors.for(:customer).for(:credit_card).on(:number)[0].message).to eq("Duplicate card exists in the vault for the customer.")
+    end
+
     it "updates the default payment method" do
       customer = Braintree::Customer.create!(
         :first_name => "Joe",
@@ -1664,7 +1685,7 @@ describe Braintree::Customer do
             :expiration_date => "06/2013",
             :options => {
               :verify_card => true,
-              :verification_merchant_account_id => SpecHelper::HiperBRLMerchantAccountId,
+              :verification_merchant_account_id => SpecHelper::CardProcessorBRLMerchantAccountId,
               :verification_account_type => "debit",
             },
           },
